summaryrefslogtreecommitdiff
path: root/jvmfwk
diff options
context:
space:
mode:
authorJoachim Lingner <jl@openoffice.org>2004-05-10 13:34:20 +0000
committerJoachim Lingner <jl@openoffice.org>2004-05-10 13:34:20 +0000
commit79a305d2fa51fb2c4ed70f1bbcca130217828dff (patch)
treee748e3fd968e206f78be5ea915ce935ab9d6df7c /jvmfwk
parent8b080d10c17200c32663a6f718da9230808bea44 (diff)
#i20052#
Diffstat (limited to 'jvmfwk')
-rw-r--r--jvmfwk/inc/jvmfwk/vendorplugin.h10
-rw-r--r--jvmfwk/plugins/sunmajor/pluginlib/sunjavaplugin.cxx10
-rw-r--r--jvmfwk/plugins/sunmajor/pluginlib/sunjavaplugin.map6
-rw-r--r--jvmfwk/source/framework.cxx66
-rw-r--r--jvmfwk/source/framework.hxx10
5 files changed, 51 insertions, 51 deletions
diff --git a/jvmfwk/inc/jvmfwk/vendorplugin.h b/jvmfwk/inc/jvmfwk/vendorplugin.h
index 2369d49cf209..2f5a71313658 100644
--- a/jvmfwk/inc/jvmfwk/vendorplugin.h
+++ b/jvmfwk/inc/jvmfwk/vendorplugin.h
@@ -2,9 +2,9 @@
*
* $RCSfile: vendorplugin.h,v $
*
- * $Revision: 1.6 $
+ * $Revision: 1.7 $
*
- * last change: $Author: jl $ $Date: 2004-05-07 14:49:40 $
+ * last change: $Author: jl $ $Date: 2004-05-10 14:34:19 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -102,7 +102,7 @@ typedef enum
JFW_PLUGIN_E_INVALID_ARG,
JFW_PLUGIN_E_WRONG_VERSION_FORMAT
*/
-javaPluginError getAllJavaInfos(
+javaPluginError jfw_plugin_getAllJavaInfos(
rtl_uString *sMinVersion,
rtl_uString *sMaxVersion,
rtl_uString * * arExcludeList,
@@ -119,7 +119,7 @@ javaPluginError getAllJavaInfos(
JFW_PLUGIN_E_FAILED_VERSION
JFW_PLUGIN_E_NO_JRE
*/
-javaPluginError getJavaInfoByPath(
+javaPluginError jfw_plugin_getJavaInfoByPath(
rtl_uString *path,
rtl_uString *sMinVersion,
rtl_uString *sMaxVersion,
@@ -139,7 +139,7 @@ javaPluginError getJavaInfoByPath(
JFW_PLUGIN_E_VM_CREATION_FAILED
*/
-javaPluginError startJavaVirtualMachine(
+javaPluginError jfw_plugin_startJavaVirtualMachine(
const JavaInfo *info,
const JavaVMOption* options,
sal_Int32 cOptions,
diff --git a/jvmfwk/plugins/sunmajor/pluginlib/sunjavaplugin.cxx b/jvmfwk/plugins/sunmajor/pluginlib/sunjavaplugin.cxx
index 34b4094dd1df..a392b91c366a 100644
--- a/jvmfwk/plugins/sunmajor/pluginlib/sunjavaplugin.cxx
+++ b/jvmfwk/plugins/sunmajor/pluginlib/sunjavaplugin.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: sunjavaplugin.cxx,v $
*
- * $Revision: 1.8 $
+ * $Revision: 1.9 $
*
- * last change: $Author: jl $ $Date: 2004-05-07 14:49:41 $
+ * last change: $Author: jl $ $Date: 2004-05-10 14:34:19 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -219,7 +219,7 @@ void abort_handler()
}
namespace cssu = com::sun::star::uno;
extern "C"
-javaPluginError getAllJavaInfos( rtl_uString *sMinVersion,
+javaPluginError jfw_plugin_getAllJavaInfos( rtl_uString *sMinVersion,
rtl_uString *sMaxVersion,
rtl_uString * *arExcludeList,
sal_Int32 nLenList,
@@ -260,7 +260,7 @@ javaPluginError getAllJavaInfos( rtl_uString *sMinVersion,
}
extern "C"
-javaPluginError getJavaInfoByPath(
+javaPluginError jfw_plugin_getJavaInfoByPath(
rtl_uString *path,
rtl_uString *sMinVersion,
rtl_uString *sMaxVersion,
@@ -335,7 +335,7 @@ javaPluginError getJavaInfoByPath(
</p>
*/
extern "C"
-javaPluginError startJavaVirtualMachine(
+javaPluginError jfw_plugin_startJavaVirtualMachine(
const JavaInfo *pInfo,
const JavaVMOption* arOptions,
sal_Int32 cOptions,
diff --git a/jvmfwk/plugins/sunmajor/pluginlib/sunjavaplugin.map b/jvmfwk/plugins/sunmajor/pluginlib/sunjavaplugin.map
index 9c02ac5d3a1d..db75c9611076 100644
--- a/jvmfwk/plugins/sunmajor/pluginlib/sunjavaplugin.map
+++ b/jvmfwk/plugins/sunmajor/pluginlib/sunjavaplugin.map
@@ -1,8 +1,8 @@
UDK_3_0_0 {
global:
- getAllJavaInfos;
- getJavaInfoByPath;
- startJavaVirtualMachine;
+ jfw_plugin_getAllJavaInfos;
+ jfw_plugin_getJavaInfoByPath;
+ jfw_plugin_startJavaVirtualMachine;
local:
*;
};
diff --git a/jvmfwk/source/framework.hxx b/jvmfwk/source/framework.hxx
index 9a289f4fd5ec..df6006a88b7e 100644
--- a/jvmfwk/source/framework.hxx
+++ b/jvmfwk/source/framework.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: framework.hxx,v $
*
- * $Revision: 1.2 $
+ * $Revision: 1.3 $
*
- * last change: $Author: jl $ $Date: 2004-04-26 11:20:34 $
+ * last change: $Author: jl $ $Date: 2004-05-10 14:34:20 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -71,7 +71,7 @@
/** typedefs for functions from vendorplugin.h
*/
-typedef javaPluginError (*getAllJavaInfos_ptr)(
+typedef javaPluginError (*jfw_plugin_getAllJavaInfos_ptr)(
rtl_uString * sMinVersion,
rtl_uString * sMaxVersion,
rtl_uString * * arExcludeList,
@@ -79,7 +79,7 @@ typedef javaPluginError (*getAllJavaInfos_ptr)(
JavaInfo*** parJavaInfo,
sal_Int32 *nLenInfoList);
-typedef javaPluginError (*getJavaInfoByPath_ptr)(
+typedef javaPluginError (*jfw_plugin_getJavaInfoByPath_ptr)(
rtl_uString * sPath,
rtl_uString * sMinVersion,
rtl_uString * sMaxVersion,
@@ -93,7 +93,7 @@ typedef javaPluginError (*getJavaInfoByPath_ptr)(
during instantiation.
</p>
*/
-typedef javaPluginError (*startJavaVirtualMachine_ptr)(
+typedef javaPluginError (*jfw_plugin_startJavaVirtualMachine_ptr)(
const JavaInfo *info,
const JavaVMOption* options,
sal_Int32 cOptions,
diff --git a/jvmfwk/source/framework.cxx b/jvmfwk/source/framework.cxx
index 7db040eeb566..31e7f5e9406c 100644
--- a/jvmfwk/source/framework.cxx
+++ b/jvmfwk/source/framework.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: framework.cxx,v $
*
- * $Revision: 1.13 $
+ * $Revision: 1.14 $
*
- * last change: $Author: jl $ $Date: 2004-05-07 14:49:41 $
+ * last change: $Author: jl $ $Date: 2004-05-10 14:34:20 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -132,11 +132,11 @@ javaFrameworkError SAL_CALL jfw_findAllJREs(JavaInfo ***pparInfo, sal_Int32 *pSi
errcode = jfw::getVendorPluginURLs(doc, context, & vecPlugins);
if (errcode != JFW_E_NONE)
return errcode;
//Add the JavaInfos found by getAllJavaInfos to the vector
//Make sure that the contents are destroyed if this
//function returns with an error
std::vector<JavaInfo*> vecInfo;
//Add the JavaInfos found by getJavaInfoByPath to this vector
//Make sure that the contents are destroyed if this
//function returns with an error
std::vector<JavaInfo*> vecInfoManual;
@@ -174,9 +174,9 @@ javaFrameworkError SAL_CALL jfw_findAllJREs(JavaInfo ***pparInfo, sal_Int32 *pSi
freeJavaInfo);
return JFW_E_NO_PLUGIN;
}
- getAllJavaInfos_ptr getAllJavaFunc =
- (getAllJavaInfos_ptr) pluginLib.getSymbol(
- rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("getAllJavaInfos")));
+ jfw_plugin_getAllJavaInfos_ptr getAllJavaFunc =
+ (jfw_plugin_getAllJavaInfos_ptr) pluginLib.getSymbol(
+ rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("jfw_plugin_getAllJavaInfos")));
OSL_ASSERT(getAllJavaFunc);
if (getAllJavaFunc == NULL)
@@ -213,12 +213,12 @@ javaFrameworkError SAL_CALL jfw_findAllJREs(JavaInfo ***pparInfo, sal_Int32 *pSi
//Check if the current plugin can detect JREs at the location
// of the paths added by jfw_setJRELocations or jfw_addJRELocation
//get the function from the plugin
- getJavaInfoByPath_ptr getJavaInfoByPathFunc =
- (getJavaInfoByPath_ptr) pluginLib.getSymbol(
- rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("getJavaInfoByPath")));
+ jfw_plugin_getJavaInfoByPath_ptr jfw_plugin_getJavaInfoByPathFunc =
+ (jfw_plugin_getJavaInfoByPath_ptr) pluginLib.getSymbol(
+ rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("jfw_plugin_getJavaInfoByPath")));
- OSL_ASSERT(getJavaInfoByPathFunc);
- if (getJavaInfoByPathFunc == NULL)
+ OSL_ASSERT(jfw_plugin_getJavaInfoByPathFunc);
+ if (jfw_plugin_getJavaInfoByPathFunc == NULL)
{ //delete JavaInfo objects
std::for_each(vecInfo.begin(), vecInfo.end(), freeJavaInfo);
std::for_each(vecInfoManual.begin(), vecInfoManual.end(),
@@ -232,7 +232,7 @@ javaFrameworkError SAL_CALL jfw_findAllJREs(JavaInfo ***pparInfo, sal_Int32 *pSi
rtl::OUString sLocation =
rtl::OStringToOUString(*ii, RTL_TEXTENCODING_UTF8);
JavaInfo* pInfo = NULL;
- plerr = (*getJavaInfoByPathFunc)(
+ plerr = (*jfw_plugin_getJavaInfoByPathFunc)(
sLocation.pData,
versionInfo.sMinVersion.pData,
versionInfo.sMaxVersion.pData,
@@ -335,7 +335,7 @@ javaFrameworkError SAL_CALL jfw_startVM(JavaVMOption *arOptions, sal_Int32 cOpti
(jfw::wasJavaSelectedInSameProcess() == true))
return JFW_E_NEED_RESTART;
//get the function startJavaVirtualMachine
rtl::OUString sLibPath;
if ((errcode = jfw::getPluginLibrary(sLibPath)) != JFW_E_NONE)
return errcode;
@@ -344,9 +344,9 @@ javaFrameworkError SAL_CALL jfw_startVM(JavaVMOption *arOptions, sal_Int32 cOpti
return JFW_E_NO_PLUGIN;
rtl::OUString sFunctionName(
- RTL_CONSTASCII_USTRINGPARAM("startJavaVirtualMachine"));
- startJavaVirtualMachine_ptr pFunc =
- (startJavaVirtualMachine_ptr)
+ RTL_CONSTASCII_USTRINGPARAM("jfw_plugin_startJavaVirtualMachine"));
+ jfw_plugin_startJavaVirtualMachine_ptr pFunc =
+ (jfw_plugin_startJavaVirtualMachine_ptr)
osl_getSymbol(modulePlugin, sFunctionName.pData);
if (pFunc == NULL)
return JFW_E_ERROR;
@@ -491,9 +491,9 @@ javaFrameworkError SAL_CALL jfw_findAndSelectJRE(JavaInfo **pInfo)
if (pluginLib.is() == sal_False)
return JFW_E_NO_PLUGIN;
- getAllJavaInfos_ptr getAllJavaFunc =
- (getAllJavaInfos_ptr) pluginLib.getSymbol(
- rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("getAllJavaInfos")));
+ jfw_plugin_getAllJavaInfos_ptr getAllJavaFunc =
+ (jfw_plugin_getAllJavaInfos_ptr) pluginLib.getSymbol(
+ rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("jfw_plugin_getAllJavaInfos")));
OSL_ASSERT(getAllJavaFunc);
if (getAllJavaFunc == NULL)
@@ -540,7 +540,7 @@ javaFrameworkError SAL_CALL jfw_findAndSelectJRE(JavaInfo **pInfo)
break;
}
}
//The array returned by getAllJavaInfos must be freed as well as
//its contents
for (int i = 0; i < cInfos; i++)
jfw_freeJavaInfo(arInfos[i]);
@@ -577,12 +577,12 @@ javaFrameworkError SAL_CALL jfw_findAndSelectJRE(JavaInfo **pInfo)
//Check if the current plugin can detect JREs at the location
// of the paths added by jfw_setJRELocations or jfw_addJRELocation
//get the function from the plugin
- getJavaInfoByPath_ptr getJavaInfoByPathFunc =
- (getJavaInfoByPath_ptr) pluginLib.getSymbol(
- rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("getJavaInfoByPath")));
+ jfw_plugin_getJavaInfoByPath_ptr jfw_plugin_getJavaInfoByPathFunc =
+ (jfw_plugin_getJavaInfoByPath_ptr) pluginLib.getSymbol(
+ rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("jfw_plugin_getJavaInfoByPath")));
- OSL_ASSERT(getJavaInfoByPathFunc);
- if (getJavaInfoByPathFunc == NULL)
+ OSL_ASSERT(jfw_plugin_getJavaInfoByPathFunc);
+ if (jfw_plugin_getJavaInfoByPathFunc == NULL)
return JFW_E_ERROR;
typedef std::vector<rtl::OString>::const_iterator citLoc;
@@ -592,7 +592,7 @@ javaFrameworkError SAL_CALL jfw_findAndSelectJRE(JavaInfo **pInfo)
rtl::OUString sLocation =
rtl::OStringToOUString(*i, RTL_TEXTENCODING_UTF8);
JavaInfo* pInfo = NULL;
- javaPluginError err = (*getJavaInfoByPathFunc)(
+ javaPluginError err = (*jfw_plugin_getJavaInfoByPathFunc)(
sLocation.pData,
versionInfo.sMinVersion.pData,
versionInfo.sMaxVersion.pData,
@@ -767,19 +767,19 @@ javaFrameworkError SAL_CALL jfw_getJavaInfoByPath(
if (pluginLib.is() == sal_False)
return JFW_E_NO_PLUGIN;
- getJavaInfoByPath_ptr getJavaInfoByPathFunc =
- (getJavaInfoByPath_ptr) pluginLib.getSymbol(
- rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("getJavaInfoByPath")));
+ jfw_plugin_getJavaInfoByPath_ptr jfw_plugin_getJavaInfoByPathFunc =
+ (jfw_plugin_getJavaInfoByPath_ptr) pluginLib.getSymbol(
+ rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("jfw_plugin_getJavaInfoByPath")));
- OSL_ASSERT(getJavaInfoByPathFunc);
- if (getJavaInfoByPathFunc == NULL)
+ OSL_ASSERT(jfw_plugin_getJavaInfoByPathFunc);
+ if (jfw_plugin_getJavaInfoByPathFunc == NULL)
continue;
//ask the plugin if this is a JRE.
//If so check if it meets the version requirements.
//Only if it does return a JavaInfo
JavaInfo* pInfo = NULL;
- javaPluginError plerr = (*getJavaInfoByPathFunc)(
+ javaPluginError plerr = (*jfw_plugin_getJavaInfoByPathFunc)(
pPath,
versionInfo.sMinVersion.pData,
versionInfo.sMaxVersion.pData,
@@ -132,11 +132,11 @@ javaFrameworkError SAL_CALL jfw_findAllJREs(JavaInfo ***pparInfo, sal_Int32 *pSi
if (errcode != JFW_E_NONE)
return errcode;
- //Add the JavaInfos found by getAllJavaInfos to the vector
+ //Add the JavaInfos found by jfw_plugin_getAllJavaInfos to the vector
//Make sure that the contents are destroyed if this
//function returns with an error
@@ -132,11 +132,11 @@ javaFrameworkError SAL_CALL jfw_findAllJREs(JavaInfo ***pparInfo, sal_Int32 *pSi
//function returns with an error
std::vector<JavaInfo*> vecInfo;
- //Add the JavaInfos found by getJavaInfoByPath to this vector
+ //Add the JavaInfos found by jfw_plugin_getJavaInfoByPath to this vector
//Make sure that the contents are destroyed if this
//function returns with an error
@@ -335,7 +335,7 @@ javaFrameworkError SAL_CALL jfw_startVM(JavaVMOption *arOptions, sal_Int32 cOpti
(jfw::wasJavaSelectedInSameProcess() == true))
return JFW_E_NEED_RESTART;
- //get the function startJavaVirtualMachine
+ //get the function jfw_plugin_startJavaVirtualMachine
rtl::OUString sLibPath;
if ((errcode = jfw::getPluginLibrary(sLibPath)) != JFW_E_NONE)
@@ -540,7 +540,7 @@ javaFrameworkError SAL_CALL jfw_findAndSelectJRE(JavaInfo **pInfo)
}
}
- //The array returned by getAllJavaInfos must be freed as well as
+ //The array returned by jfw_plugin_getAllJavaInfos must be freed as well as
//its contents
for (int i = 0; i < cInfos; i++)